@@ -82,7 +82,9 @@ enum econf_err {
   /** File is a sym link which is not permitted */
   ECONF_ERROR_FILE_IS_SYM_LINK = 20,
   /** User defined parsing callback has failed **/
-  ECONF_PARSING_CALLBACK_FAILED = 21
+  ECONF_PARSING_CALLBACK_FAILED = 21,
+  /** Given argument is NULL */
+  ECONF_ARGUMENT_IS_NULL_VALUE = 22
 };
 
 typedef enum econf_err econf_err;
